summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAyushee Shah <ayushee.shah@intel.com>2020-12-08 15:20:54 -0800
committerCommit Bot <commit-bot@chromium.org>2020-12-10 18:26:43 +0000
commitb5a5c7b205e72e862abe751644d9eee124bb1c2c (patch)
tree76dbbd0813957d697b47fb1d507de2844ae1823e
parente200d3747d694c8137f254ac1000169d541f2822 (diff)
downloadchrome-ec-b5a5c7b205e72e862abe751644d9eee124bb1c2c.tar.gz
TCPMv2: Enter USB4 mode if cable supports TBT_SS_U32_GEN1 speed
If cable supports TBT_SS_U32_GEN1 i.e. 10Gbps per lane, enable entering USB4 mode BUG=b:175139039 BRANCH=None TEST=Able to enter into USB4 mode with Thunderbolt Gen 1 cables Signed-off-by: Ayushee Shah <ayushee.shah@intel.com> Change-Id: I10684f96e8d6e67b1086fbc560ec372e7f5b6cba Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/2580851 Reviewed-by: Tanu Malhotra <tanu.malhotra@intel.com> Reviewed-by: Abe Levkoy <alevkoy@chromium.org>
-rw-r--r--common/usb_pd_alt_mode_dfp.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/common/usb_pd_alt_mode_dfp.c b/common/usb_pd_alt_mode_dfp.c
index 151e6c2594..1c1801ff75 100644
--- a/common/usb_pd_alt_mode_dfp.c
+++ b/common/usb_pd_alt_mode_dfp.c
@@ -894,7 +894,7 @@ __overridable enum tbt_compat_cable_speed board_get_max_tbt_speed(int port)
* the port and the response received from the cable, whichever is least.
*
* For Cable rev 2.0: If get_tbt_cable_speed() is less than
* TBT_SS_U32_GEN1_GEN2, return USB_R30_SS_U2_ONLY speed since the board
* doesn't support superspeed else the USB4 cable speed is set according to
* the cable response.
*/
@@ -905,7 +905,7 @@ enum usb_rev30_ss get_usb4_cable_speed(int port)
enum usb_rev30_ss max_usb4_speed;
- if (tbt_speed < TBT_SS_U32_GEN1_GEN2)
+ if (tbt_speed < TBT_SS_U31_GEN1)
return USB_R30_SS_U2_ONLY;
/*
@@ -894,7 +894,7 @@ __overridable enum tbt_compat_cable_speed board_get_max_tbt_speed(int port)
*
* For Cable rev 2.0: If get_tbt_cable_speed() is less than
- * TBT_SS_U32_GEN1_GEN2, return USB_R30_SS_U2_ONLY speed since the board
+ * TBT_SS_U31_GEN1, return USB_R30_SS_U2_ONLY speed since the board
* doesn't support superspeed else the USB4 cable speed is set according to
* the cable response.